@@ -9,7 +9,7 @@ import random
 import inspect
 from pydub import AudioSegment
 from GenerIter.process import Process
-from GenerIter.util import debug
+from GenerIter.util import debug, nextPowerOf2
 import GenerIter.excepts as robox
 
 class Mix(Process):
@@ -26,7 +26,7 @@ class Mix(Process):
         if nvoices < 2:
             raise robox.GIParameterErr("Insufficient voices specified for the multitrack algorithm")
 
-        mute = 1.5 * (float)newtPowerOf2(nvoices)
+        mute = 1.5 * (float)nextPowerOf2(nvoices)
 
         for ctr in range(iterations):
             audios = []
